@@ -1,14 +1,20 @@
 package commands
 
 import (
+	"io/ioutil"
+	"os"
 	"sync"
 	"sync/atomic"
 	"testing"
 	"time"
 
+	"github.com/gofrs/flock"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
+	"github.com/stretchr/testify/require"
+
 	"gitlab.com/gitlab-org/gitlab-runner/common"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 )
 
 func TestProcessRunner_BuildLimit(t *testing.T) {
@@ -87,14 +93,15 @@ func TestProcessRunner_BuildLimit(t *testing.T) {
 
 	runners := make(chan *common.RunnerConfig)
 
-	// Start 5 builds.
+	// Start 2 builds.
 	wg := sync.WaitGroup{}
-	wg.Add(5)
-	for i := 0; i < 5; i++ {
+	wg.Add(2)
+	for i := 0; i < 2; i++ {
 		go func(i int) {
 			defer wg.Done()
 
-			cmd.processRunner(i, &cfg, runners)
+			err := cmd.processRunner(i, &cfg, runners)
+			assert.NoError(t, err)
 		}(i)
 	}
 
@@ -103,9 +110,80 @@ func TestProcessRunner_BuildLimit(t *testing.T) {
 		time.Sleep(10 * time.Millisecond)
 	}
 
-	err := cmd.processRunner(6, &cfg, runners)
+	err := cmd.processRunner(3, &cfg, runners)
 	assert.EqualError(t, err, "failed to request job, runner limit met")
 
 	// Wait for all builds to finish.
 	wg.Wait()
 }
+
+func runFileLockingCmd(t *testing.T, wg *sync.WaitGroup, started chan bool, stop chan bool, filePath string, shouldPanic bool) {
+	cmd := &RunCommand{
+		configOptionsWithListenAddress: configOptionsWithListenAddress{
+			configOptions: configOptions{
+				ConfigFile: filePath,
+				config: &common.Config{
+					Concurrent: 5,
+				},
+			},
+		},
+		stopSignals:  make(chan os.Signal),
+		reloadSignal: make(chan os.Signal, 1),
+		runFinished:  make(chan bool, 1),
+	}
+
+	go func() {
+		if shouldPanic {
+			assert.Panics(t, cmd.RunWithLock, "Expected the Runner to create a new lock")
+		} else {
+			assert.NotPanics(t, cmd.RunWithLock, "Expected the Runner to reject creating a new lock")
+		}
+		wg.Done()
+	}()
+
+	close(started)
+
+	<-stop
+	cmd.stopSignal = os.Kill
+}
+
+func TestMulti_RunWithLock(t *testing.T) {
+	defer helpers.MakeFatalToPanic()()
+
+	file, err := ioutil.TempFile("", "config.toml")
+	require.NoError(t, err)
+
+	err = file.Close()
+	require.NoError(t, err)
+
+	filePath := file.Name()
+
+	wg := new(sync.WaitGroup)
+	stop := make(chan bool)
+
+	wg.Add(2)
+
+	started := make(chan bool)
+	go runFileLockingCmd(t, wg, started, stop, filePath, false)
+	<-started
+
+	time.Sleep(1 * time.Second)
+
+	started = make(chan bool)
+	go runFileLockingCmd(t, wg, started, stop, filePath, true)
+	<-started
+
+	time.Sleep(1 * time.Second)
+
+	close(stop)
+	wg.Wait()
+
+	// Try to lock the file to check if it was properly unlocked while
+	// finishing cmd.RunWithLock() call
+	fl := flock.New(filePath)
+	locked, err := fl.TryLock()
+	defer fl.Unlock()
+
+	assert.True(t, locked, "File was not unlocked!")
+	assert.NoError(t, err)
+}
