@@ -13,7 +13,8 @@ const HealthyChecks = 3
 const HealthCheckInterval = 3600
 const DefaultWaitForServicesTimeout = 30
 const ShutdownTimeout = 30
-const DefaultOutputLimit = 4096 // 4MB in kilobytes
+const DefaultOutputLimit = 4 * 1024 * 1024 // in bytes
+const DefaultTracePatchLimit = 1024 * 1024 // in bytes
 const ForceTraceSentInterval = 30 * time.Second
 const PreparationRetries = 3
 const DefaultGetSourcesAttempts = 1
