@@ -2,10 +2,13 @@ package parser
 
 import (
 	"regexp"
-	"strings"
+
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/path"
 )
 
-type baseParser struct{}
+type baseParser struct {
+	path path.Path
+}
 
 // The way how matchesToVolumeSpecParts parses the volume mount specification and assigns
 // parts was inspired by how Docker Engine's `windowsParser` is created. The original sources
@@ -16,7 +19,7 @@ type baseParser struct{}
 // The original source is licensed under Apache License 2.0 and the copyright for it
 // goes to Docker, Inc.
 func (p *baseParser) matchesToVolumeSpecParts(spec string, specExp *regexp.Regexp) (map[string]string, error) {
-	match := specExp.FindStringSubmatch(strings.ToLower(spec))
+	match := specExp.FindStringSubmatch(spec)
 
 	if len(match) == 0 {
 		return nil, NewInvalidVolumeSpecErr(spec)
@@ -24,7 +27,7 @@ func (p *baseParser) matchesToVolumeSpecParts(spec string, specExp *regexp.Regex
 
 	matchgroups := make(map[string]string)
 	for i, name := range specExp.SubexpNames() {
-		matchgroups[name] = strings.ToLower(match[i])
+		matchgroups[name] = match[i]
 	}
 
 	parts := map[string]string{
@@ -42,3 +45,7 @@ func (p *baseParser) matchesToVolumeSpecParts(spec string, specExp *regexp.Regex
 
 	return parts, nil
 }
+
+func (p *baseParser) Path() path.Path {
+	return p.path
+}
